struct ClassicContext {
elem: Trusted<HTMLScriptElement>,
kind: ExternalScriptKind,
character_encoding: &'static Encoding,
data: Vec<u8>,
metadata: Option<Metadata>,
url: ServoUrl,
status: Result<(), NetworkError>,
fetch_options: ScriptFetchOptions,
response_was_cors_cross_origin: bool,
}Expand description
The context required for asynchronously loading an external script source.
Fields
elem: Trusted<HTMLScriptElement>The element that initiated the request.
kind: ExternalScriptKindThe kind of external script.
character_encoding: &'static EncodingThe (fallback) character encoding argument to the “fetch a classic script” algorithm.
data: Vec<u8>The response body received to date.
metadata: Option<Metadata>The response metadata received to date.
url: ServoUrlThe initial URL requested.
status: Result<(), NetworkError>Indicates whether the request failed, and why
fetch_options: ScriptFetchOptionsThe fetch options of the script
response_was_cors_cross_origin: boolUsed to set muted errors flag of classic scripts