#[repr(C)]pub(crate) struct HTMLScriptElement {Show 14 fields
htmlelement: HTMLElement,
delaying_the_load_event: DomRefCell<Option<LoadBlocker>>,
already_started: Cell<bool>,
parser_inserted: Cell<bool>,
non_blocking: Cell<bool>,
parser_document: Dom<Document>,
preparation_time_document: MutNullableDom<Document>,
line_number: u64,
id: ScriptId,
script_text: DomRefCell<DOMString>,
from_an_external_file: Cell<bool>,
blocking: MutNullableDom<DOMTokenList>,
marked_as_render_blocking: Cell<bool>,
result: DomRefCell<Option<Result<Script, ()>>>,
}Fields
htmlelement: HTMLElementdelaying_the_load_event: DomRefCell<Option<LoadBlocker>>already_started: Cell<bool>parser_inserted: Cell<bool>non_blocking: Cell<bool>https://html.spec.whatwg.org/multipage/#non-blocking
(currently unused)
parser_document: Dom<Document>Document of the parser that created this element https://html.spec.whatwg.org/multipage/#parser-document
preparation_time_document: MutNullableDom<Document>Prevents scripts that move between documents during preparation from executing. https://html.spec.whatwg.org/multipage/#preparation-time-document
line_number: u64Track line line_number
id: ScriptIdUnique id for each script element
script_text: DomRefCell<DOMString>from_an_external_file: Cell<bool>blocking: MutNullableDom<DOMTokenList>marked_as_render_blocking: Cell<bool>Used to keep track whether we consider this script element render blocking during
prepare
result: DomRefCell<Option<Result<Script, ()>>>Implementations
Sourceimpl HTMLScriptElement
impl HTMLScriptElement
fn __assert_parent_type(&self)
Sourceimpl HTMLScriptElement
impl HTMLScriptElement
fn new_inherited( local_name: LocalName, prefix: Option<Prefix>, document: &Document, creator: ElementCreator, ) -> HTMLScriptElement
pub(crate) fn new( cx: &mut JSContext, local_name: LocalName, prefix: Option<Prefix>, document: &Document, proto: Option<HandleObject<'_>>, creator: ElementCreator, ) -> DomRoot<HTMLScriptElement>
pub(crate) fn get_script_id(&self) -> ScriptId
Sourcefn delay_load_event(&self, document: &Document, url: ServoUrl)
fn delay_load_event(&self, document: &Document, url: ServoUrl)
Marks that element as delaying the load event or not.
https://html.spec.whatwg.org/multipage/#concept-script-delay-load https://html.spec.whatwg.org/multipage/#delaying-the-load-event-flag
Sourcefn get_script_kind(&self, script_type: ScriptType) -> ExternalScriptKind
fn get_script_kind(&self, script_type: ScriptType) -> ExternalScriptKind
Helper method to determine the script kind based on attributes and insertion context.
This duplicates the script preparation logic from the HTML spec to determine the script’s active document without full preparation.
https://html.spec.whatwg.org/multipage/#prepare-the-script-element
Sourcefn get_script_active_document(
&self,
script_kind: ExternalScriptKind,
) -> DomRoot<Document>
fn get_script_active_document( &self, script_kind: ExternalScriptKind, ) -> DomRoot<Document>
Sourceimpl HTMLScriptElement
impl HTMLScriptElement
Sourcepub(crate) fn set_initial_script_text(&self)
pub(crate) fn set_initial_script_text(&self)
Sourcefn prepare_the_script_text(&self, cx: &mut JSContext) -> Fallible<()>
fn prepare_the_script_text(&self, cx: &mut JSContext) -> Fallible<()>
fn has_render_blocking_attribute(&self) -> bool
Sourcefn potentially_render_blocking(&self) -> bool
fn potentially_render_blocking(&self) -> bool
Sourcepub(crate) fn prepare(
&self,
cx: &mut JSContext,
introduction_type_override: Option<&'static CStr>,
)
pub(crate) fn prepare( &self, cx: &mut JSContext, introduction_type_override: Option<&'static CStr>, )
pub(crate) fn queue_error_event(&self)
pub(crate) fn get_script_type(&self) -> Option<ScriptType>
pub(crate) fn set_parser_inserted(&self, parser_inserted: bool)
pub(crate) fn get_parser_inserted(&self) -> bool
pub(crate) fn set_already_started(&self, already_started: bool)
pub(crate) fn get_non_blocking(&self) -> bool
fn dispatch_event(&self, cx: &mut JSContext, type_: Atom) -> bool
fn text(&self) -> DOMString