HTMLScriptElement

Struct HTMLScriptElement 

#[repr(C)]
pub(crate) struct HTMLScriptElement {
Show 13 fields htmlelement: HTMLElement, delaying_the_load_event: DomRefCell<Option<LoadBlocker>>, already_started: Cell<bool>, parser_inserted: Cell<bool>, non_blocking: Cell<bool>, parser_document: Dom<Document>, preparation_time_document: MutNullableDom<Document>, line_number: u64, id: ScriptId, script_text: DomRefCell<DOMString>, from_an_external_file: Cell<bool>, blocking: MutNullableDom<DOMTokenList>, marked_as_render_blocking: Cell<bool>,
}

Fields

htmlelement: HTMLElementdelaying_the_load_event: DomRefCell<Option<LoadBlocker>>already_started: Cell<bool>parser_inserted: Cell<bool>non_blocking: Cell<bool>parser_document: Dom<Document>

Document of the parser that created this element https://html.spec.whatwg.org/multipage/#parser-document

preparation_time_document: MutNullableDom<Document>

Prevents scripts that move between documents during preparation from executing. https://html.spec.whatwg.org/multipage/#preparation-time-document

line_number: u64

Track line line_number

id: ScriptId

Unique id for each script element

script_text: DomRefCell<DOMString>from_an_external_file: Cell<bool>blocking: MutNullableDom<DOMTokenList>marked_as_render_blocking: Cell<bool>

Used to keep track whether we consider this script element render blocking during prepare

Implementations

Source

impl HTMLScriptElement

Source

impl HTMLScriptElement

fn new_inherited( local_name: LocalName, prefix: Option<Prefix>, document: &Document, creator: ElementCreator, ) -> HTMLScriptElement

pub(crate) fn new( cx: &mut JSContext, local_name: LocalName, prefix: Option<Prefix>, document: &Document, proto: Option<HandleObject<'_>>, creator: ElementCreator, ) -> DomRoot<HTMLScriptElement>

pub(crate) fn get_script_id(&self) -> ScriptId

pub(crate) fn delay_load_event(&self, url: ServoUrl)

Marks that element as delaying the load event or not.

Nothing happens if the element was already delaying the load event and we pass true to that method again.

https://html.spec.whatwg.org/multipage/#concept-script-delay-load https://html.spec.whatwg.org/multipage/#delaying-the-load-event-flag

pub(crate) fn get_script_kind(&self) -> ExternalScriptKind

Helper method to determine the script kind based on attributes and insertion context.

This duplicates the script preparation logic from the HTML spec to determine the script’s active document without full preparation.

https://html.spec.whatwg.org/multipage/#prepare-the-script-element

pub(crate) fn get_script_active_document(&self) -> DomRoot<Document>

Source

impl HTMLScriptElement